@@ -1,23 +1,18 @@
-#' Plot Method for a Nested frailty model and an Additive frailty model.
+#' Plot Method for a Nested frailty model.
 #' 
 #' Plots estimated baseline survival and hazard functions (output from an
-#' object of class 'NestedPenal' for nested frailty models and an object 
-#' of class'additivePenal' object for additive frailty model ). 
+#' object of class 'NestedPenal' for nested frailty models). 
 #' Confidence bands are allowed.
 #' 
 #' 
-#' @aliases plot.nestedPenal lines.nestedPenal plot.additivePenal lines.additivePenal
+#' @aliases plot.nestedPenal lines.nestedPenal
 #' @usage
 #' \method{plot}{nestedPenal}(x, type.plot="Hazard", conf.bands=TRUE,
 #' pos.legend="topright", cex.legend=0.7, main, color=2, median=TRUE, Xlab = "Time", Ylab =
 #' "Hazard function", ...)
-#' \method{plot}{additivePenal}(x, type.plot="Hazard", conf.bands=TRUE,
-#' pos.legend="topright", cex.legend=0.7, main, color=2, median=TRUE, Xlab = "Time", Ylab =
-#' "Hazard function", ...)
 #' 
 #' @param x A nested model, i.e. an object of class \code{frailtyPenal} for
-#' Nested frailty models (output from calling \code{frailtyPenal} function), or
-#' a fitted additive frailty model (output from calling \code{additivePenal}).
+#' Nested frailty models (output from calling \code{frailtyPenal} function).
 #' @param type.plot a character string specifying the type of curve. Possible
 #' value are "Hazard", or "Survival". The default is "Hazard". Only the first
 #' words are required, e.g "Haz", "Su"
@@ -44,7 +39,7 @@
 #' @examples
 #' 
 #' 
-#' \dontrun{
+#' \donttest{
 #' 
 #' data(dataNested)
 #' modNested <- frailtyPenal(Surv(t1,t2,event)~cluster(group)+
@@ -53,19 +48,10 @@
 #' 
 #' plot(modNested,conf.bands=FALSE)
 #' 
-#' data(dataAdditive)
-#' 
-#' modAdd <- additivePenal(Surv(t1,t2,event)~cluster(group)+var1+slope(var1),
-#' correlation=TRUE,data=dataAdditive,n.knots=8,kappa=862,hazard="Splines")
-#' 
-#' #-- 'var1' is boolean as a treatment variable
-#' 
-#' plot(modAdd)
-#' 
 #' }
 #' 
 #' 
-"plot.nestedPenal" <- "plot.additivePenal" <- function (x, type.plot="Hazard", conf.bands=TRUE, pos.legend="topright", cex.legend=0.7, main, color=2, median=TRUE, Xlab = "Time", Ylab = "Hazard function", ...)
+"plot.nestedPenal" <- function (x, type.plot="Hazard", conf.bands=TRUE, pos.legend="topright", cex.legend=0.7, main, color=2, median=TRUE, Xlab = "Time", Ylab = "Hazard function", ...)
 {
   
   plot.type <- charmatch(type.plot, c("Hazard", "Survival"),nomatch = 0)
