@@ -396,7 +396,7 @@
     double precision::betaR,etaR,betaD,etaD
     double precision::vet,vet2,alpha,theta
     double precision,dimension(2)::su,sut1,sut0,sudc
-    double precision::lam,lamdc,temp
+    double precision::lam,lamdc,temp, tempscl
     double precision::logGammaJ
 
     n = 0
@@ -476,7 +476,8 @@
             if (c(k).eq.1) then
                 select case(typeof)
                     case(0)
-                        call susps(t1(k),the1,nz1,su,lam,zi)
+                        call susps(t1(k),the1,nz1,tempscl,lam,zi)
+                        su = tempscl
                         if (t1(k).eq.date(ndate)) then
                             lam = 4.d0*the1(n-2-1)/(zi(n-2)-zi(n-2-1))
                         endif
@@ -544,7 +545,8 @@
     if (cdc(i).eq.1) then
         select case(typeof)
             case(0)
-                call susps(t1dc(i),the2,nz2,sudc,lamdc,zi)
+                call susps(t1dc(i),the2,nz2,tempscl,lamdc,zi)
+                sudc = tempscl
                 if (t1dc(i).eq.datedc(ndatedc)) then
                     lamdc = 4.d0*the2(n-2-1)/(zi(n-2)-zi(n-2-1))
                 endif
@@ -600,7 +602,7 @@
     double precision::betaR,etaR,betaD,etaD
     double precision::vet,vet2,alpha,theta
     double precision,dimension(2)::su,sut1,sut0,sudc
-    double precision::lam,lamdc,temp
+    double precision::lam,lamdc,temp, tempscl
     double precision::logGammaJ
 
     n = 0
@@ -676,7 +678,8 @@
             if (c(k).eq.1) then
                 select case(typeof)
                     case(0)
-                        call susps(t1(k),the1,nz1,su,lam,zi)
+                        call susps(t1(k),the1,nz1,tempscl,lam,zi)
+                            su = tempscl
                         if (t1(k).eq.date(ndate)) then
                             lam = 4.d0*the1(n-2-1)/(zi(n-2)-zi(n-2-1))
                         endif
