@@ -412,7 +412,7 @@
     double precision::betaR,etaR,betaD,etaD
     double precision::vet,vet2,sig2,alpha
     double precision,dimension(2)::su,sut1,sut0,sudc
-    double precision::lam,lamdc,temp
+    double precision::lam,lamdc,temp, tempscl
     double precision,parameter::pi=3.141592653589793d0
     
     n = 0
@@ -492,7 +492,8 @@
             if (c(k).eq.1) then
                 select case(typeof)
                     case(0)
-                        call susps(t1(k),the1,nz1,su,lam,zi)
+                        call susps(t1(k),the1,nz1,tempscl,lam,zi)
+                        su = tempscl
                         if (t1(k).eq.date(ndate)) then
                             lam = 4.d0*the1(n-2-1)/(zi(n-2)-zi(n-2-1))
                         endif
@@ -560,7 +561,8 @@
     if (cdc(i).eq.1) then
         select case(typeof)
             case(0)
-                call susps(t1dc(i),the2,nz2,sudc,lamdc,zi)
+                call susps(t1dc(i),the2,nz2,tempscl,lamdc,zi)
+                sudc = tempscl
                 if (t1dc(i).eq.datedc(ndatedc)) then
                     lamdc = 4.d0*the2(n-2-1)/(zi(n-2)-zi(n-2-1))
                 endif
@@ -618,7 +620,7 @@
     double precision::betaR,etaR,betaD,etaD
     double precision::vet,vet2,sig2,alpha
     double precision,dimension(2)::su,sut1,sut0,sudc
-    double precision::lam,lamdc,temp
+    double precision::lam,lamdc,temp, tempscl
     double precision,parameter::pi=3.141592653589793d0
 
     n = 0
@@ -694,7 +696,8 @@
             if (c(k).eq.1) then
                 select case(typeof)
                     case(0)
-                        call susps(t1(k),the1,nz1,su,lam,zi)
+                        call susps(t1(k),the1,nz1,tempscl,lam,zi)
+                        su = tempscl
                         if (t1(k).eq.date(ndate)) then
                             lam = 4.d0*the1(n-2-1)/(zi(n-2)-zi(n-2-1))
                         endif
